@@ -3,7 +3,7 @@ use wasm_bindgen::prelude::*;
 
 #[wasm_bindgen(module = "crypto")]
 extern {
-    #[wasm_bindgen(extends = Object)]
-    #[derive(Clone, Debug, PartialEq)]
+    #[wasm_bindgen(extends = Object, js_name = "ECDH")]
+    #[derive(Clone, Debug)]
     pub type Ecdh;
 }
