@@ -4,7 +4,7 @@ use wasm_bindgen::prelude::*;
 #[wasm_bindgen(module = "events")]
 extern {
     #[wasm_bindgen(extends = Object)]
-    #[derive(Clone, Debug, Eq, PartialEq)]
+    #[derive(Clone, Debug)]
     pub type Immediate;
 
     #[wasm_bindgen(method, js_name = "hasRef")]
